@@ -23,9 +23,11 @@ def unpack_df(df):
     return a
 
 def autocomplete_teamname(name):
-    for n in team_names_men:
-        if name in n:
-            return n 
+    for m,w in zip(team_names_men, team_names_women):
+        if name in m:
+            return m
+        elif name in w:
+            return w
     return None
 
 def scrape_pdf(file, upper_bound, left_bound, lower_bound, right_bound, debug):
@@ -34,20 +36,30 @@ def scrape_pdf(file, upper_bound, left_bound, lower_bound, right_bound, debug):
         logging.debug(res)
 
     return unpack_df(res)
-    
+
+def resolve_names(numbers, teams, team, gender):
+    names = []
+    for num in numbers:
+        try:
+            names.append(teams[team][str(num)])
+        except:
+            logging.warn(f"Failed to match shirt number #{num} to a {gender} in team {team}!")
+            return None
+    return names
+
 def extract_players(upper_bound, lower_bound, ateam, file, debug):
     team_numbers = scrape_pdf(file, upper_bound, 20, lower_bound, 40, debug)
-    # Unpack names based on player number
-    names = []
-    for num in team_numbers:
-        try:
-            names.append(teams_men[ateam][str(num)])
-        except:
-            logging.error("Failed to match players against shirt numbers - check constants.py")
-            return None
+
+    # Unpack names based on player number - men's (in case of failure try women's)
+    names = resolve_names(team_numbers, teams_men, ateam, 'men')
+    if names is None:
+        names = resolve_names(team_numbers, teams_women, ateam, 'women')
+    if not names:
+        raise Exception("Failed to resolve numbers to names while processing")
+
     logging.info(f"Players names from {ateam}: {names}")
 
-	# call the function for each item in parallel
+    # call the function for each item in parallel
     pool = multiprocessing.Pool()
     conf = [(file, upper_bound, 190, lower_bound, 240, debug),
             (file, upper_bound, 230, lower_bound, 250, debug),
@@ -81,6 +93,7 @@ def process_pdf(file, debug):
     logging.info("Processing PDF...")
     try:
         game = scrape_pdf(file, 40, 300, 85, 480, debug)
+        logging.info(game)
         team1, team2 = game
         if (ateam1 := autocomplete_teamname(team1)) is None:
             logging.error(f"Failed to resolve team name: {team1}")
@@ -105,5 +118,6 @@ def process_pdf(file, debug):
         logging.info(players2)
 
         return result, date, location, ateam1, ateam2, players1, players2
-    except:
+    except Exception as e:
+        logging.error(e)
         return None
\ No newline at end of file
